@@ -1,6 +1,7 @@
 use std::path::PathBuf;
 
 use clap::Parser;
+use clap_verbosity_flag::{InfoLevel, Verbosity};
 use regex::Regex;
 
 /// CLI configuration for mdrefcheck
@@ -18,7 +19,13 @@ pub struct CliConfig {
     /// Paths to not check. Excluded files can be parsed though if they are referred.
     #[arg(long, short, value_name = "PATH")]
     pub exclude: Vec<PathBuf>,
-    // /// Files to not check and parse.
-    // #[arg(long, num_args = 1.., value_delimiter = ' ', value_name = "FILE")]
-    // pub full_exclude_files: Vec<PathBuf>,
+
+    /// Disable standard ignore filters (gitignore, hidden files, etc.)
+    #[arg(long)]
+    pub no_ignore: bool,
+
+    // -q, --quiet   (decreases verbosity)
+    // -v, --verbose (increases verbosity, up to 2 times for 'trace')
+    #[command(flatten)]
+    pub verbosity: Verbosity<InfoLevel>,
 }
